Package: ggrefine
Title: Publication-Quality 'ggplot2' Themes
Version: 0.5.0
Authors@R: 
    person(given = "David", family = "Hodge", 
           email = "davidhodge931@gmail.com", 
           role = c("aut", "cre", "cph"), 
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Complete themes for publication-quality 'ggplot2' visualisation. 
    Also provides functions to modify these based on the positional axis scales 
    and orientation of a particular plot. 
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/ggrefine,
        https://davidhodge931.github.io/ggrefine/
BugReports: https://github.com/davidhodge931/ggrefine/issues
Depends: R (>= 4.1.0)
Imports: blends, flexoki, ggplot2 (>= 4.0.0), grid, jumble, rlang,
        scales, viridis
Suggests: knitr, patchwork, rmarkdown, spelling
Encoding: UTF-8
Language: en-GB
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-07 04:37:20 UTC; david
Author: David Hodge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-07 05:00:02 UTC
Built: R 4.5.2; ; 2026-07-07 06:47:25 UTC; unix
