Package: ggrefine
Title: Publication-Quality 'ggplot2' Themes
Version: 0.4.0
Authors@R: 
    person(given = "David", family = "Hodge", 
           email = "davidhodge931@gmail.com", 
           role = c("aut", "cre", "cph"), 
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Complete themes for publication-quality 'ggplot2' visualisation. 
    Also provides functions to modify these based on the positional axis scales 
    and focus of a particular plot. 
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/ggrefine,
        https://davidhodge931.github.io/ggrefine/
BugReports: https://github.com/davidhodge931/ggrefine/issues
Depends: R (>= 4.1.0)
Imports: blends, flexoki, ggplot2, grid, jumble, rlang, scales, viridis
Suggests: knitr, patchwork, rmarkdown, spelling
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-04 02:33:14 UTC; david
Author: David Hodge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 13:10:10 UTC
Built: R 4.6.0; ; 2026-05-04 17:20:15 UTC; unix
