% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/refine.R
\name{refine_void}
\alias{refine_void}
\title{Void refine}
\usage{
refine_void(x_type = "continuous", y_type = "continuous", focus = NULL, ...)
}
\arguments{
\item{x_type}{Character. Type of x-axis: "continuous", "binned", or "discrete".}

\item{y_type}{Character. Type of y-axis: "continuous", "binned", or "discrete".}

\item{focus}{Character. The primary axis of interest: "x" or "y". Gridlines
and axis elements are removed from the opposite axis. If \code{NULL} (default),
focus is inferred from \code{x_type} and \code{y_type}: discrete x with continuous/binned
y gives \code{"x"}, continuous/binned x with discrete y gives \code{"y"}, otherwise \code{"x"}.}

\item{...}{Additional arguments (currently unused).}
}
\value{
A ggplot2 theme object
}
\description{
Removes axes and gridlines.
}
\examples{
library(ggplot2)

set_theme(new = theme_grey())

p_continuous <- mpg |>
  ggplot(aes(x = displ, y = hwy)) +
  geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_x <- mpg |>
  ggplot(aes(x = drv, y = hwy)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

p_discrete_y <- mpg |>
  ggplot(aes(x = hwy, y = drv)) +
  geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))

patchwork::wrap_plots(
  p_continuous + ggrefine::refine_modern() + labs(title = "ggrefine::refine_modern"),
  p_discrete_x + ggrefine::refine_modern(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_modern(y_type = "discrete"),
  p_continuous + ggrefine::refine_classic() + labs(title = "ggrefine::refine_classic"),
  p_discrete_x + ggrefine::refine_classic(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_classic(y_type = "discrete"),
  p_continuous + ggrefine::refine_fusion() + labs(title = "ggrefine::refine_fusion"),
  p_discrete_x + ggrefine::refine_fusion(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_fusion(y_type = "discrete"),
  p_continuous + ggrefine::refine_void() + labs(title = "ggrefine::refine_void"),
  p_discrete_x + ggrefine::refine_void(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_void(y_type = "discrete"),
  p_continuous + ggrefine::refine_none() + labs(title = "ggrefine::refine_none"),
  p_discrete_x + ggrefine::refine_none(x_type = "discrete"),
  p_discrete_y + ggrefine::refine_none(y_type = "discrete"),
  ncol = 3
)

}
