% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_grey}
\alias{theme_grey}
\title{theme_grey-----------------------------------------------------------------}
\usage{
theme_grey(
  ...,
  text_size = 10,
  text_family = "",
  text_colour = flexoki::flexoki$base["black"],
  title_size = NULL,
  title_family = NULL,
  title_colour = NULL,
  subtitle_size = NULL,
  subtitle_family = NULL,
  subtitle_colour = NULL,
  caption_size = NULL,
  caption_family = NULL,
  caption_colour = NULL,
  caption_hjust = 0,
  legend_place = "right",
  legend_axis_line_colour = NULL,
  legend_axis_line_linewidth = NULL,
  legend_background_fill = NULL,
  legend_key_fill = NULL,
  legend_ticks_colour = NULL,
  legend_ticks_linewidth = NULL,
  legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
  axis_line_colour = NULL,
  axis_line_linewidth = 0.2,
  axis_ticks_colour = NULL,
  axis_ticks_linewidth = NULL,
  axis_ticks_length = grid::unit(3.66, "pt"),
  panel_background_fill = scales::col_mix(flexoki::flexoki$base["base100"], "white", 0.5),
  panel_grid_colour = NULL,
  panel_grid_linetype = 1,
  panel_grid_linewidth = 1,
  panel_grid_minor_linetype = 1,
  panel_grid_minor_linewidth = 0.5,
  plot_background_fill = "white",
  panel_widths = NULL,
  panel_heights = NULL
)
}
\arguments{
\item{...}{Require named arguments (and support trailing commas).}

\item{text_size}{The base size of the text theme element. Defaults to 10.}

\item{text_family}{The base family of the text theme element. Defaults to "".}

\item{text_colour}{The base colour of the text theme element.}

\item{title_size}{The size of the \code{plot.title} theme element. Defaults to \code{text_size}.}

\item{title_family}{The family of the \code{plot.title} theme element. Defaults to \code{text_family}.}

\item{title_colour}{The colour of the \code{plot.title} theme element. Defaults to \code{text_colour}.}

\item{subtitle_size}{The size of the \code{plot.subtitle} theme element. Defaults to \code{text_size}.}

\item{subtitle_family}{The family of the \code{plot.subtitle} theme element. Defaults to \code{text_family}.}

\item{subtitle_colour}{The colour of the \code{plot.subtitle} theme element. Defaults to \code{text_colour}.}

\item{caption_size}{The size of the \code{plot.caption} theme element. Defaults to \code{text_size}.}

\item{caption_family}{The family of the \code{plot.caption} theme element. Defaults to \code{text_family}.}

\item{caption_colour}{The colour of the \code{plot.caption} theme element. Defaults to \code{text_colour}.}

\item{caption_hjust}{The horizontal justification of the \code{plot.caption} theme element. Defaults to 0.}

\item{legend_place}{The place of the legend. Either "right", "top" or "bottom".}

\item{legend_axis_line_colour}{The colour of the legend.axis.line theme element.}

\item{legend_axis_line_linewidth}{The linewidth of the legend.axis.line theme element.}

\item{legend_background_fill}{The fill (and colour) of the \code{legend.background} theme element.}

\item{legend_key_fill}{The fill (and colour) of the legend.key theme element.}

\item{legend_ticks_colour}{The colour of the legend.ticks theme element.}

\item{legend_ticks_linewidth}{The linewidth of the legend.ticks theme element.}

\item{legend_ticks_length}{The length of the legend.ticks.length theme element.}

\item{axis_line_colour}{The colour of the axis.line theme element. Defaults to \code{text_colour}.}

\item{axis_line_linewidth}{The linewidth of the axis.line theme element.}

\item{axis_ticks_colour}{The colour of the axis.ticks theme element.}

\item{axis_ticks_linewidth}{The linewidth of the axis.ticks theme element.}

\item{axis_ticks_length}{The length of the axis.ticks.length theme element.}

\item{panel_background_fill}{The fill (and colour) of the panel.background theme element.}

\item{panel_grid_colour}{The colour of the panel.grid theme element.}

\item{panel_grid_linetype}{The linetype of the panel.grid.major theme element.}

\item{panel_grid_linewidth}{The linewidth of the panel.grid.major theme element.}

\item{panel_grid_minor_linetype}{The linetype of the panel.grid.minor theme element.}

\item{panel_grid_minor_linewidth}{The linewidth of the panel.grid.minor theme element.}

\item{plot_background_fill}{The fill (and colour) of the plot.background theme element.}

\item{panel_widths}{The panel.widths theme element. A \code{unit} or unit vector setting the width of
individual panels, or a single unit for the total panel area width. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}

\item{panel_heights}{The panel.heights theme element. A \code{unit} or unit vector setting the height of
individual panels, or a single unit for the total panel area height. Overrides aspect ratio set
by the theme, coord, or facets. Defaults to \code{NULL}.}
}
\value{
A ggplot theme.
}
\description{
A complete theme for a coloured panel background on a white plot
background. Defaults to using a panel grid colour that multiply blends the
panel background fill with itself.
}
\details{
Grey theme
}
